pub struct StackedLayout {
pub sorted_cols: Vec<(usize, usize, StackedSlice)>,
pub mat_starts: Vec<usize>,
/* private fields */
}Fields
sorted_cols: Vec<(usize, usize, StackedSlice)>The columns of the unstacked matrices in sorted order. Each entry (matrix index, column index, coordinate) contains the pointer (matrix index, column index) to a column of the
unstacked collection of matrices as well as coordinate which is a pointer to where the
column starts in the stacked matrix.
mat_starts: Vec<usize>mat_starts[mat_idx] is the index in sorted_cols where the matrix with index mat_idx
starts.
Implementations
Sourceimpl StackedLayout
impl StackedLayout
Sourceimpl StackedLayout
impl StackedLayout
Sourcepub fn new(
l_skip: usize,
log_stacked_height: usize,
sorted: Vec<(usize, usize)>,
) -> Result<Self, StackedPcsError>
pub fn new( l_skip: usize, log_stacked_height: usize, sorted: Vec<(usize, usize)>, ) -> Result<Self, StackedPcsError>
Computes the layout of greedily stacking columns with dimension metadata given by sorted
into a stacked matrix.
l_skipis a threshold log2 height: if a column has height less than2^l_skip, it is stacked as a column of height2^l_skipwith stride2^{l_skip - log_height}.log_stacked_heightis the log2 height of the stacked matrix.sortedis Vec of(width, log_height)that must already be sorted in descending order oflog_height.
Sourcepub fn from_raw_parts(
l_skip: usize,
log_stacked_height: usize,
sorted_cols: Vec<(usize, usize, StackedSlice)>,
) -> Result<Self, StackedPcsError>
pub fn from_raw_parts( l_skip: usize, log_stacked_height: usize, sorted_cols: Vec<(usize, usize, StackedSlice)>, ) -> Result<Self, StackedPcsError>
Raw unsafe constructor
pub fn unstacked_slices_iter(&self) -> impl Iterator<Item = &StackedSlice>
Sourcepub fn get(&self, mat_idx: usize, col_idx: usize) -> Option<&StackedSlice>
pub fn get(&self, mat_idx: usize, col_idx: usize) -> Option<&StackedSlice>
(mat_idx, col_idx) should be indexing into the unstacked collection of matrices.
pub fn width_of(&self, mat_idx: usize) -> usize
Sourcepub fn mat_view<'a, F>(
&self,
unstacked_mat_idx: usize,
stacked_matrix: &'a ColMajorMatrix<F>,
) -> StridedColMajorMatrixView<'a, F>
pub fn mat_view<'a, F>( &self, unstacked_mat_idx: usize, stacked_matrix: &'a ColMajorMatrix<F>, ) -> StridedColMajorMatrixView<'a, F>
Due to the definition of stacking, in a column major matrix the lifted columns of the unstacked matrix will always be contiguous in memory within the stacked matrix, so we can return the sub-view.