pub struct StackedSlice {
pub col_idx: usize,
pub row_idx: usize,
/* private fields */
}Expand description
Pointer to the location of a sub-column within the stacked matrix.
This struct contains length information, but information from StackedLayout (namely l_skip)
is needed to determine if this is a strided slice or not.
Fields
col_idx: usizerow_idx: usizeImplementations
Sourceimpl StackedSlice
impl StackedSlice
Sourcepub fn log_height(&self) -> usize
pub fn log_height(&self) -> usize
The true log height. If >= l_skip, no striding. Otherwise striding by 2^{l_skip - log_height}.
Sourceimpl StackedSlice
impl StackedSlice